import subprocess
import sys


def colored_text(text, color):
    colors = {
        "green": "\033[92m",
        "yellow": "\033[93m",
        "red": "\033[91m",
        "reset": "\033[0m",
    }
    return f"{colors[color]}{text}{colors['reset']}"


def is_package_installed(package_name):
    return bool(get_installed_package(package_name).strip())


def get_installed_version(package_name):
    result = get_installed_package(package_name).splitlines()
    for line in result:
        if line.startswith("Version:"):
            return line.split()[1]


def get_installed_package(package_name: str) -> str | None:
    try:
        result = subprocess.run(
            [sys.executable, "-m", "pip", "show", package_name],
            capture_output=True,
            text=True,
            check=True,
        )
        return result.stdout
    except subprocess.CalledProcessError:
        return None



import subprocess
import sys
from utils import colored_text, is_package_installed, get_installed_version
from requirements_manager import update_requirements, remove_from_requirements

GROUP_REQUIREMENTS = {
    "prod": "requirements.txt",
    "dev": "requirements-dev.txt",
    "test": "requirements-test.txt",
}


def install_package(package_name, group="prod"):
    try:
        subprocess.run(
            [sys.executable, "-m", "pip", "install", package_name], check=True
        )
        print(colored_text(f"PACOTE: {package_name} instalado com sucesso!", "green"))
    except subprocess.CalledProcessError:
        print(colored_text(f"Erro ao instalar {package_name}", "red"))
        return

    package_name = package_name.split("==")[0]
    version = get_installed_version(package_name)

    if version:
        update_requirements(package_name, version, GROUP_REQUIREMENTS[group])
    else:
        print(colored_text(f"Erro ao obter a versão do {package_name}", "red"))


def uninstall_package(package_name):
    """Desinstala um pacote do ambiente e remove de todos os arquivos de requirements"""
    package_name = package_name.split("==")[0]
    if not is_package_installed(package_name):
        print(colored_text(f"{package_name} não está instalado.", "yellow"))
        return

    try:
        subprocess.run(
            [sys.executable, "-m", "pip", "uninstall", "-y", package_name], check=True
        )
        print(
            colored_text(f"PACOTE: {package_name} desinstalado com sucesso!", "green")
        )
    except subprocess.CalledProcessError:
        print(colored_text(f"Erro ao desinstalar {package_name}", "red"))
        return

    # Remover o pacote de TODOS os arquivos de requirements
    for group_file in GROUP_REQUIREMENTS.values():
        remove_from_requirements(package_name, group_file)



from setuptools import find_packages, setup

setup(
    name="pipg",
    version="0.2.0",
    packages=find_packages(),
    install_requires=[],
    entry_points={
        "console_scripts": [
            "pipg = pipg.cli:main",
        ],
    },
    author="Guilherme Gonçalves Soares",
    author_email="guilherme16.gon@gmail.com",
    description="Um wrapper simples para o pip que instala e já escreve o nome e a versão do pacote no requirements.txt",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/GuilhermeGonSoares/pipg",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
